@@ -53,9 +53,8 @@ import static com.openexchange.chronos.provider.CalendarFolderProperty.COLOR;
 import static com.openexchange.chronos.provider.CalendarFolderProperty.COLOR_LITERAL;
 import static com.openexchange.chronos.provider.CalendarFolderProperty.DESCRIPTION;
 import static com.openexchange.chronos.provider.CalendarFolderProperty.DESCRIPTION_LITERAL;
-import static com.openexchange.chronos.provider.CalendarFolderProperty.USED_FOR_SYNC;
-import static com.openexchange.chronos.provider.CalendarFolderProperty.USED_FOR_SYNC_LITERAL;
 import static com.openexchange.chronos.provider.CalendarFolderProperty.optPropertyValue;
+import static com.openexchange.chronos.provider.CalendarFolderProperty.USED_FOR_SYNC_LITERAL;
 import static com.openexchange.chronos.provider.ical.ICalCalendarConstants.NAME;
 import static com.openexchange.chronos.provider.ical.ICalCalendarConstants.PROVIDER_ID;
 import static com.openexchange.chronos.provider.ical.ICalCalendarConstants.REFRESH_INTERVAL;
@@ -65,6 +64,7 @@ import static com.openexchange.java.Autoboxing.L;
 import java.util.EnumSet;
 import java.util.Locale;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.concurrent.TimeUnit;
 import org.dmfs.rfc5545.Duration;
 import org.json.JSONObject;
@@ -74,6 +74,7 @@ import com.openexchange.chronos.exception.CalendarExceptionCodes;
 import com.openexchange.chronos.provider.CalendarAccount;
 import com.openexchange.chronos.provider.CalendarAccountAttribute;
 import com.openexchange.chronos.provider.CalendarCapability;
+import com.openexchange.chronos.provider.UsedForSync;
 import com.openexchange.chronos.provider.basic.BasicCalendarAccess;
 import com.openexchange.chronos.provider.basic.CalendarSettings;
 import com.openexchange.chronos.provider.caching.CachingCalendarUtils;
@@ -184,10 +185,6 @@ public class BasicICalCalendarProvider extends BasicCachingCalendarProvider {
         if (Strings.isEmpty(description)) {
             description = feedResponse.getFeedDescription();
         }
-        Boolean usedForSync = optPropertyValue(settings.getExtendedProperties(), USED_FOR_SYNC_LITERAL, Boolean.class);
-        if (null == usedForSync || false == CachingCalendarUtils.canBeUsedForSync(PROVIDER_ID, session)) {
-            usedForSync = Boolean.FALSE;
-        }
         String name = settings.getName();
         if (Strings.isEmpty(name)) {
             name = Strings.isNotEmpty(feedResponse.getFeedName()) ? feedResponse.getFeedName() : "Calendar";
@@ -211,8 +208,10 @@ public class BasicICalCalendarProvider extends BasicCachingCalendarProvider {
         if (null != description) {
             proposedExtendedProperties.add(DESCRIPTION(description, false));
         }
-        if (null != usedForSync) {
-            proposedExtendedProperties.add(USED_FOR_SYNC(usedForSync, false == CachingCalendarUtils.canBeUsedForSync(PROVIDER_ID, session)));
+        if (canBeUsedForSync(session) == false) {
+            proposedSettings.setUsedForSync(UsedForSync.DEACTIVATED);
+        } else if (settings.getUsedForSync().isPresent()) {
+            proposedSettings.setUsedForSync(settings.getUsedForSync().get());
         }
         proposedSettings.setConfig(proposedConfig);
         proposedSettings.setExtendedProperties(proposedExtendedProperties);
@@ -221,6 +220,15 @@ public class BasicICalCalendarProvider extends BasicCachingCalendarProvider {
         return proposedSettings;
     }
 
+    /**
+     * Checks if the provider can be used for sync
+     *
+     * @param session The users session
+     */
+    private boolean canBeUsedForSync(Session session) {
+        return CachingCalendarUtils.canBeUsedForSync(PROVIDER_ID, session);
+    }
+
     private void addAuthInfo(JSONObject proposedConfig, AdvancedAuthInfo authInfo) {
         if (authInfo != null && authInfo.getAuthType() == AuthType.BASIC) {
             String login = authInfo.getLogin();
@@ -270,11 +278,11 @@ public class BasicICalCalendarProvider extends BasicCachingCalendarProvider {
         if (Strings.isNotEmpty(description)) {
             internalConfig.putSafe("description", description);
         }
-        Boolean usedForSyncValue = optPropertyValue(settings.getExtendedProperties(), USED_FOR_SYNC_LITERAL, Boolean.class);
-        if (null != usedForSyncValue) {
-            boolean usedForSync = usedForSyncValue.booleanValue();
+        Optional<UsedForSync> optUsedForSync = settings.getUsedForSync();
+        if (optUsedForSync.isPresent()) {
+            boolean usedForSync = optUsedForSync.get().isUsedForSync();
             if (false == internalConfig.has(USED_FOR_SYNC_LITERAL) || usedForSync != internalConfig.optBoolean(USED_FOR_SYNC_LITERAL, false)) {
-                if (usedForSync && false == CachingCalendarUtils.canBeUsedForSync(PROVIDER_ID, session)) {
+                if (canBeUsedForSync(session) == false) {
                     throw CalendarExceptionCodes.INVALID_CONFIGURATION.create(USED_FOR_SYNC_LITERAL);
                 }
                 internalConfig.putSafe(USED_FOR_SYNC_LITERAL, B(usedForSync));
@@ -319,15 +327,16 @@ public class BasicICalCalendarProvider extends BasicCachingCalendarProvider {
                 internalConfig.putSafe("description", description);
                 changed = true;
             }
-            Boolean usedForSync = optPropertyValue(settings.getExtendedProperties(), USED_FOR_SYNC_LITERAL, Boolean.class);
-            if (usedForSync != null) {
-                if (!internalConfig.has(USED_FOR_SYNC_LITERAL) || !Objects.equals(usedForSync, B(internalConfig.optBoolean(USED_FOR_SYNC_LITERAL)))) {
-                    if (usedForSync.booleanValue() && false == CachingCalendarUtils.canBeUsedForSync(PROVIDER_ID, session)) {
-                        throw CalendarExceptionCodes.INVALID_CONFIGURATION.create(USED_FOR_SYNC_LITERAL);
-                    }
-                    internalConfig.putSafe(USED_FOR_SYNC_LITERAL, usedForSync);
-                    changed = true;
+        }
+        Optional<UsedForSync> optUsedForSync = settings.getUsedForSync();
+        if(optUsedForSync.isPresent()) {
+            boolean usedForSync = optUsedForSync.get().isUsedForSync();
+            if (!internalConfig.has(USED_FOR_SYNC_LITERAL) || usedForSync != internalConfig.optBoolean(USED_FOR_SYNC_LITERAL)) {
+                if (usedForSync && false == canBeUsedForSync(session)) {
+                    throw CalendarExceptionCodes.INVALID_CONFIGURATION.create(USED_FOR_SYNC_LITERAL);
                 }
+                internalConfig.putSafe(USED_FOR_SYNC_LITERAL, B(usedForSync));
+                changed = true;
             }
         }
         if (settings.containsName() && false == Objects.equals(settings.getName(), internalConfig.optString("name", null))) {
