@@ -66,11 +66,10 @@ import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
 import org.apache.http.NoHttpResponseException;
 import org.apache.http.client.ClientProtocolException;
-import org.apache.http.client.methods.CloseableHttpResponse;
+import org.apache.http.client.HttpClient;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.http.client.utils.DateUtils;
-import org.apache.http.impl.client.CloseableHttpClient;
 import com.openexchange.auth.info.AuthInfo;
 import com.openexchange.auth.info.AuthType;
 import com.openexchange.chronos.ical.ICalParameters;
@@ -84,16 +83,12 @@ import com.openexchange.chronos.provider.ical.properties.ICalCalendarProviderPro
 import com.openexchange.chronos.provider.ical.result.GetResponse;
 import com.openexchange.chronos.provider.ical.result.GetResponseState;
 import com.openexchange.chronos.provider.ical.utils.ICalProviderUtils;
-import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
-import com.openexchange.net.ssl.SSLSocketFactoryProvider;
-import com.openexchange.net.ssl.config.SSLConfigurationService;
+import com.openexchange.rest.client.httpclient.HttpClientService;
 import com.openexchange.rest.client.httpclient.HttpClients;
-import com.openexchange.rest.client.httpclient.HttpClients.ClientConfig;
 import com.openexchange.session.Session;
-import com.openexchange.version.VersionService;
 
 /**
  *
@@ -183,12 +178,15 @@ public class ICalFeedClient {
      * Returns the calendar behind the given feed URL if available. If there is no update (based on etag and last modification header) the contained calendar will be <code>null</code>.
      *
      * @return GetResponse containing the feed content
+     * @throws OXException
      */
     public GetResponse executeRequest() throws OXException {
         ICalProviderUtils.verifyURI(this.iCalFeedConfig.getFeedUrl());
         HttpGet request = prepareGet();
 
-        try (CloseableHttpResponse response = ICalFeedHttpClient.getInstance().execute(request)) {
+        HttpResponse response = null;
+        try {
+            response = getHttpClient().execute(request);
             int statusCode = assertStatusCode(response);
             if (statusCode == HttpStatus.SC_NOT_MODIFIED) {
                 // OK, nothing was modified, no response body, return as is
@@ -208,10 +206,15 @@ public class ICalFeedClient {
             LOG.error("Error while processing the retrieved information:{}.", e.getMessage(), e);
             throw ICalProviderExceptionCodes.IO_ERROR.create(e, e.getMessage());
         } finally {
-            reset(request);
+            HttpClients.close(request, response);
         }
     }
 
+    private HttpClient getHttpClient() throws OXException {
+        HttpClientService httpClientService = Services.getServiceLookup().getServiceSafe(HttpClientService.class);
+        return httpClientService.getHttpClient("icalfeed");
+    }
+
     private GetResponse prepareResponse(URI uri, HttpResponse httpResponse) throws OXException {
         GetResponse response = new GetResponse(uri, GetResponseState.MODIFIED, httpResponse.getAllHeaders());
 
@@ -272,67 +275,6 @@ public class ICalFeedClient {
         }
     }
 
-    public static void reset() {
-        ICalFeedHttpClient.reset();
-    }
-
-    private static class ICalFeedHttpClient {
-
-        private static volatile CloseableHttpClient httpClient;
-
-        static CloseableHttpClient getInstance() {
-            CloseableHttpClient tmp = httpClient;
-            if (tmp == null) {
-                synchronized (ICalFeedHttpClient.class) {
-                    tmp = httpClient;
-                    if (tmp == null) {
-                        ClientConfig config = ClientConfig.newInstance("icalfeed");
-                        config.setDenyLocalRedirect(true);
-                        config.setUserAgent(initUserAgent());
-                        initConfig(config);
-                        tmp = HttpClients.getHttpClient(config, Services.getService(SSLSocketFactoryProvider.class), Services.getService(SSLConfigurationService.class));
-                        httpClient = tmp;
-                    }
-                }
-            }
-            return tmp;
-        }
-
-        static String initUserAgent() {
-            VersionService versionService = Services.getService(VersionService.class);
-            String versionString = null;
-            if (null == versionService) {
-                versionString = "<unknown version>";
-            } else {
-                versionString = versionService.getVersionString();
-            }
-            return VersionService.NAME + "/" + versionString;
-        }
-
-        static void initConfig(ClientConfig config) {
-            LeanConfigurationService leanConfigurationService = Services.getService(LeanConfigurationService.class);
-            int maxConnections = leanConfigurationService.getIntProperty(ICalCalendarProviderProperties.maxConnections);
-            config.setMaxTotalConnections(maxConnections);
-
-            int maxConnectionsPerRoute = leanConfigurationService.getIntProperty(ICalCalendarProviderProperties.maxConnectionsPerRoute);
-            config.setMaxConnectionsPerRoute(maxConnectionsPerRoute);
-
-            int connectionTimeout = leanConfigurationService.getIntProperty(ICalCalendarProviderProperties.connectionTimeout);
-            config.setConnectionTimeout(connectionTimeout);
-
-            int socketReadTimeout = leanConfigurationService.getIntProperty(ICalCalendarProviderProperties.socketReadTimeout);
-            config.setSocketReadTimeout(socketReadTimeout);
-        }
-
-        static void reset() {
-            CloseableHttpClient tmp = httpClient;
-            if (tmp != null) {
-                httpClient = null;
-                HttpClients.shutDown(tmp);
-            }
-        }
-    }
-
     /**
      * Prepares an appropriate exception for a response with status <code>401 Unauthorized</code>.
      *
