@@ -63,11 +63,6 @@ public class PreferencesActivator extends HousekeepingActivator {
         registerService(PreferencesItemService.class, new Enabled());
     }
 
-    @Override
-    public void stopBundle() throws Exception {
-        closeTrackers();
-    }
-
     @Override
     protected Class<?>[] getNeededServices() {
         // Nothing to do
